==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_fields/QUOTATIONLINEIDS_Type.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour QUOTATIONLINEIDS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="QUOTATIONLINEIDS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUOTATIONLINEID" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "QUOTATIONLINEIDS_Type", propOrder = {
    "quotationlineid"
})
public class QUOTATIONLINEIDS_Type {

    @XmlElement(name = "QUOTATIONLINEID", required = true)
    protected List<QUOTATIONLINEID_Type> quotationlineid;

    /**
     * Gets the value of the quotationlineid property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the quotationlineid property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getQUOTATIONLINEID().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link QUOTATIONLINEID_Type }
     * 
     * 
     */
    public List<QUOTATIONLINEID_Type> getQUOTATIONLINEID() {
        if (quotationlineid == null) {
            quotationlineid = new ArrayList<QUOTATIONLINEID_Type>();
        }
        return this.quotationlineid;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/QUOTATIONLINEIDS_Type.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for QUOTATIONLINEIDS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="QUOTATIONLINEIDS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUOTATIONLINEID" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "QUOTATIONLINEIDS_Type", propOrder = {
    "quotationlineid"
})
public class QUOTATIONLINEIDS_Type {

    @XmlElement(name = "QUOTATIONLINEID", required = true)
    protected List<QUOTATIONLINEID_Type> quotationlineid;

    /**
     * Gets the value of the quotationlineid property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the quotationlineid property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getQUOTATIONLINEID().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link QUOTATIONLINEID_Type }
     * 
     * 
     */
    public List<QUOTATIONLINEID_Type> getQUOTATIONLINEID() {
        if (quotationlineid == null) {
            quotationlineid = new ArrayList<QUOTATIONLINEID_Type>();
        }
        return this.quotationlineid;
    }

}
